@@ -14,33 +14,33 @@ draw.pairwise.venn <- function(
 	area1,
 	area2,
 	cross.area,
-	category = rep("", 2),
+	category = rep('', 2),
 	euler.d = TRUE,
 	scaled = TRUE,
 	inverted = FALSE,
 	ext.text = TRUE,
 	ext.percent = rep(0.05, 3),
 	lwd = rep(2, 2),
-	lty = rep("solid", 2),
-	col = rep("black", 2),
+	lty = rep('solid', 2),
+	col = rep('black', 2),
 	fill = NULL,
 	alpha = rep(0.5, 2),
-	label.col = rep("black", 3),
+	label.col = rep('black', 3),
 	cex = rep(1, 3),
-	fontface = rep("plain", 3),
-	fontfamily = rep("serif", 3),
+	fontface = rep('plain', 3),
+	fontfamily = rep('serif', 3),
 	cat.pos = c(-50, 50),
 	cat.dist = rep(0.025, 2),
 	cat.cex = rep(1, 2),
-	cat.col = rep("black", 2),
-	cat.fontface = rep("plain", 2),
-	cat.fontfamily = rep("serif", 2),
+	cat.col = rep('black', 2),
+	cat.fontface = rep('plain', 2),
+	cat.fontfamily = rep('serif', 2),
 	cat.just = rep(list(c(0.5, 0.5)), 2),
-	cat.default.pos = "outer",
+	cat.default.pos = 'outer',
 	cat.prompts = FALSE,
 	ext.pos = rep(0, 2),
 	ext.dist = rep(0, 2),
-	ext.line.lty = "solid",
+	ext.line.lty = 'solid',
 	ext.length = rep(0.95, 2),
 	ext.line.lwd = 1,
 	rotation.degree = 0,
@@ -49,133 +49,133 @@ draw.pairwise.venn <- function(
 	sep.dist = 0.05,
 	offset = 0,
     cex.prop=NULL,
-    print.mode = "raw",
+    print.mode = 'raw',
     sigdigs=3,
 	...
 	) {
 
-	# area1 > area2 OR area1 < area2 plots the same Venn diagram.  Invert using the "inverted" argument.
+	# area1 > area2 OR area1 < area2 plots the same Venn diagram.  Invert using the 'inverted' argument.
 	# check parameter lengths and plausibility of Venn diagram
 	if (length(category) == 1) { category <- rep(category, 2); }
-	else if (length(category) != 2) { flog.error("Unexpected parameter length for 'category'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'category'"); }
+	else if (length(category) != 2) { flog.error('Unexpected parameter length for "category"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "category"'); }
 
 	if (length(ext.percent) == 1) { ext.percent <- rep(ext.percent, 3); }
-	else if (length(ext.percent) != 3) { flog.error("Unexpected parameter length for 'ext.percent'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'ext.percent'"); }
+	else if (length(ext.percent) != 3) { flog.error('Unexpected parameter length for "ext.percent"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "ext.percent"'); }
 
 	if (length(ext.pos) == 1) { ext.pos <- rep(ext.pos, 2); }
-	else if (length(ext.pos) != 2) { flog.error("Unexpected parameter length for 'ext.pos'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'ext.pos'"); }
+	else if (length(ext.pos) != 2) { flog.error('Unexpected parameter length for "ext.pos"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "ext.pos"'); }
 
 	if (length(ext.dist) == 1) { ext.dist <- rep(ext.dist, 2); }
-	else if (length(ext.dist) != 2) { flog.error("Unexpected parameter length for 'ext.dist'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'ext.dist'"); }
+	else if (length(ext.dist) != 2) { flog.error('Unexpected parameter length for "ext.dist"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "ext.dist"'); }
 
 	if (length(ext.length) == 1) { ext.length <- rep(ext.length, 2); }
-	else if (length(ext.length) != 2) { flog.error("Unexpected parameter length for 'ext.length'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'ext.length'"); }
+	else if (length(ext.length) != 2) { flog.error('Unexpected parameter length for "ext.length"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "ext.length"'); }
 
 	if (length(lwd) == 1) { lwd <- rep(lwd, 2); }
-	else if (length(lwd) != 2) { flog.error("Unexpected parameter length for 'lwd'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'lwd'"); }
+	else if (length(lwd) != 2) { flog.error('Unexpected parameter length for "lwd"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "lwd"'); }
 
 	if (length(lty) == 1) { lty <- rep(lty, 2); }
-	else if (length(lty) != 2) { flog.error("Unexpected parameter length for 'lty'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'lty'"); }
+	else if (length(lty) != 2) { flog.error('Unexpected parameter length for "lty"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "lty"'); }
 
 	if (length(col) == 1) { col <- rep(col, 2); }
-	else if (length(col) != 2) { flog.error("Unexpected parameter length for 'col'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'col'"); }
+	else if (length(col) != 2) { flog.error('Unexpected parameter length for "col"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "col"'); }
 
 	if (length(label.col) == 1) { label.col <- rep(label.col, 3); }
-	else if (length(label.col) != 3) { flog.error("Unexpected parameter length for 'label.col'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'label.col'"); }
+	else if (length(label.col) != 3) { flog.error('Unexpected parameter length for "label.col"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "label.col"'); }
 
 	if (length(cex) == 1) { cex <- rep(cex, 3); }
-	else if (length(cex) != 3) { flog.error("Unexpected parameter length for 'cex'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cex'"); }
+	else if (length(cex) != 3) { flog.error('Unexpected parameter length for "cex"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "cex"'); }
 
 	if (length(fontface) == 1) { fontface <- rep(fontface, 3); }
-	else if (length(fontface) != 3) { flog.error("Unexpected parameter length for 'fontface'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'fontface'"); }
+	else if (length(fontface) != 3) { flog.error('Unexpected parameter length for "fontface"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "fontface"'); }
 
 	if (length(fontfamily) == 1) { fontfamily <- rep(fontfamily, 3); }
-	else if (length(fontfamily) != 3) { flog.error("Unexpected parameter length for 'fontfamily'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'fontfamily'"); }
+	else if (length(fontfamily) != 3) { flog.error('Unexpected parameter length for "fontfamily"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "fontfamily"'); }
 
 	if (length(fill) == 1) { fill <- rep(fill, 2); }
-	else if (length(fill) != 2 & length(fill) != 0) { flog.error("Unexpected parameter length for 'fill'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'fill'"); }
+	else if (length(fill) != 2 & length(fill) != 0) { flog.error('Unexpected parameter length for "fill"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "fill"'); }
 
 	if (length(alpha) == 1) { alpha <- rep(alpha, 2); }
-	else if (length(alpha) != 2 & length(alpha) != 0) { flog.error("Unexpected parameter length for 'alpha'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'alpha'"); }
+	else if (length(alpha) != 2 & length(alpha) != 0) { flog.error('Unexpected parameter length for "alpha"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "alpha"'); }
 
-	if (length(ext.line.lwd) != 1) { flog.error("Unexpected parameter length for 'ext.line.lwd'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'ext.line.lwd'"); }
+	if (length(ext.line.lwd) != 1) { flog.error('Unexpected parameter length for "ext.line.lwd"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "ext.line.lwd"'); }
 
 	if (length(cat.pos) == 1) { cat.pos <- rep(cat.pos, 2); }
-	else if (length(cat.pos) != 2) { flog.error("Unexpected parameter length for 'cat.pos'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cat.pos'"); }
+	else if (length(cat.pos) != 2) { flog.error('Unexpected parameter length for "cat.pos"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "cat.pos"'); }
 
 	if (length(cat.dist) == 1) { cat.dist <- rep(cat.dist, 2); }
-	else if (length(cat.dist) != 2) { flog.error("Unexpected parameter length for 'cat.dist'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cat.dist'"); }
+	else if (length(cat.dist) != 2) { flog.error('Unexpected parameter length for "cat.dist"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "cat.dist"'); }
 
 	if (length(cat.col) == 1) { cat.col <- rep(cat.col, 2); }
-	else if (length(cat.col) != 2) { flog.error("Unexpected parameter length for 'cat.col'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cat.col'"); }
+	else if (length(cat.col) != 2) { flog.error('Unexpected parameter length for "cat.col"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "cat.col"'); }
 
 	if (length(cat.cex) == 1) { cat.cex <- rep(cat.cex, 2); }
-	else if (length(cat.cex) != 2) { flog.error("Unexpected parameter length for 'cat.cex'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cat.cex'"); }
+	else if (length(cat.cex) != 2) { flog.error('Unexpected parameter length for "cat.cex"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "cat.cex"'); }
 
 	if (length(cat.fontface) == 1) { cat.fontface <- rep(cat.fontface, 2); }
-	else if (length(cat.fontface) != 2) { flog.error("Unexpected parameter length for 'cat.fontface'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cat.fontface'"); }
+	else if (length(cat.fontface) != 2) { flog.error('Unexpected parameter length for "cat.fontface"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "cat.fontface"'); }
 
 	if (length(cat.fontfamily) == 1) { cat.fontfamily <- rep(cat.fontfamily, 2); }
-	else if (length(cat.fontfamily) != 2) { flog.error("Unexpected parameter length for 'cat.fontfamily'",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'cat.fontfamily'"); }
+	else if (length(cat.fontfamily) != 2) { flog.error('Unexpected parameter length for "cat.fontfamily"',name='VennDiagramLogger')
+stop('Unexpected parameter length for "cat.fontfamily"'); }
 
-	if (length(offset) != 1) { flog.error("Unexpected parameter length for 'offset'. Try using 'rotation.degree' to achieve non-vertical offsets",name="VennDiagramLogger")
-stop("Unexpected parameter length for 'offset'. Try using 'rotation.degree' to achieve non-vertical offsets"); }
+	if (length(offset) != 1) { flog.error('Unexpected parameter length for "Offset". Try using "rotation.degree" to achieve non-vertical offsets',name='VennDiagramLogger')
+stop('Unexpected parameter length for "Offset". Try using "rotation.degree" to achieve non-vertical offsets'); }
 
-	if (!(class(cat.just) == "list" & length(cat.just) == 2 & length(cat.just[[1]]) == 2 & length(cat.just[[2]]) == 2)) {
-		flog.error("Unexpected parameter format for 'cat.just'",name="VennDiagramLogger")
-stop("Unexpected parameter format for 'cat.just'");
+	if (!(class(cat.just) == 'list' & length(cat.just) == 2 & length(cat.just[[1]]) == 2 & length(cat.just[[2]]) == 2)) {
+		flog.error('Unexpected parameter format for "cat.just"',name='VennDiagramLogger')
+stop('Unexpected parameter format for "cat.just"');
 		}
 
 	# check uninterpretable parameters
 	if (!euler.d & scaled) {
-		flog.error("Uninterpretable parameter combination\nPlease set both euler.d = FALSE and scaled = FALSE to force Venn diagrams.",name="VennDiagramLogger")
-stop("Uninterpretable parameter combination\nPlease set both euler.d = FALSE and scaled = FALSE to force Venn diagrams.");
+		flog.error('Uninterpretable parameter combination\nPlease set both euler.d = FALSE and scaled = FALSE to force Venn diagrams.',name='VennDiagramLogger')
+stop('Uninterpretable parameter combination\nPlease set both euler.d = FALSE and scaled = FALSE to force Venn diagrams.');
 		}
 	if (offset > 1 | offset < 0) {
-		flog.error("'Offset' must be between 0 and 1.  Try using 'rotation.degree = 180' to achieve offsets in the opposite direction.",name="VennDiagramLogger")
-stop("'Offset' must be between 0 and 1.  Try using 'rotation.degree = 180' to achieve offsets in the opposite direction.");
+		flog.error('"Offset" must be between 0 and 1.  Try using "rotation.degree = 180" to achieve offsets in the opposite direction.',name='VennDiagramLogger')
+stop('"Offset" must be between 0 and 1.  Try using "rotation.degree = 180" to achieve offsets in the opposite direction.');
 		}
 
-	if (cross.area > area1 | cross.area > area2) { flog.error("Impossible: cross section area too large.",name="VennDiagramLogger")
-stop("Impossible: cross section area too large."); }
+	if (cross.area > area1 | cross.area > area2) { flog.error('Impossible: cross section area too large.',name='VennDiagramLogger')
+stop('Impossible: cross section area too large.'); }
 	cat.pos <- cat.pos + rotation.degree;
 
 	# check category label defaults
-	if (((cat.default.pos != 'outer') & (cat.default.pos != "text")) & cat.prompts) {
-	# PHH: removed this check from the if, so that code works with expressions: & isTRUE(category != rep("", 2))
-		flog.info("No default location recognized.  Automatically changing to 'outer'",name="VennDiagramLogger");
+	if (((cat.default.pos != 'outer') & (cat.default.pos != 'text')) & cat.prompts) {
+	# PHH: removed this check from the if, so that code works with expressions: & isTRUE(category != rep("', 2))
+		flog.info('No default location recognized.  Automatically changing to "outer"',name='VennDiagramLogger');
 		cat.default.pos <- 'outer';
 		}
 	if ((cat.default.pos == 'outer') & cat.prompts) {
-		flog.info("Placing category labels at default outer locations.  Use 'cat.pos' and 'cat.dist' to modify location.",name="VennDiagramLogger");
-		flog.info(paste("Current 'cat.pos':", cat.pos[1], "degrees,", cat.pos[2], "degrees"),name="VennDiagramLogger");
-		flog.info(paste("Current 'cat.dist':", cat.dist[1], ",", cat.dist[2]),name="VennDiagramLogger");
+		flog.info('Placing category labels at default outer locations.  Use "cat.pos" and "cat.dist" to modify location.',name='VennDiagramLogger');
+		flog.info(paste('Current "cat.pos":', cat.pos[1], 'degrees,', cat.pos[2], 'degrees'),name='VennDiagramLogger');
+		flog.info(paste('Current "cat.dist":', cat.dist[1], ',', cat.dist[2]),name='VennDiagramLogger');
 		}
 	if ((cat.default.pos == 'text') & cat.prompts) {
-		flog.info("Placing category labels at default text locations.  Use 'cat.pos' and 'cat.dist' to modify location.",name="VennDiagramLogger");
-		flog.info(paste("Current 'cat.pos':", cat.pos[1], "degrees,", cat.pos[2], "degrees"),name="VennDiagramLogger");
-		flog.info(paste("Current 'cat.dist':", cat.dist[1], ",", cat.dist[2]),name="VennDiagramLogger");
+		flog.info('Placing category labels at default text locations.  Use "cat.pos" and "cat.dist" to modify location.',name='VennDiagramLogger');
+		flog.info(paste('Current "cat.pos":', cat.pos[1], 'degrees,', cat.pos[2], 'degrees'),name='VennDiagramLogger');
+		flog.info(paste('Current "cat.dist":', cat.dist[1], ',', cat.dist[2]),name='VennDiagramLogger');
 		}
 
 	max.circle.size = 0.2;
@@ -224,13 +224,13 @@ stop("Impossible: cross section area too large."); }
 		cex <- rev(cex);
 		fontface <- rev(fontface);
 		fontfamily <- rev(fontfamily);
-		cat.pos <- rev(cat.pos);
-		cat.dist <- rev(cat.dist);
+		#cat.pos <- rev(cat.pos);
+		#cat.dist <- rev(cat.dist);
 		cat.col <- rev(cat.col);
-		cat.cex <- rev(cat.cex);
-		cat.fontface <- rev(cat.fontface);
-		cat.fontfamily <- rev(cat.fontfamily);
-		cat.just <- rev(cat.just);
+		#cat.cex <- rev(cat.cex);
+		#cat.fontface <- rev(cat.fontface);
+		#cat.fontfamily <- rev(cat.fontfamily);
+		#cat.just <- rev(cat.just);
 		ext.pos <- rev(ext.pos);
 		#ext.dist <- rev(ext.dist); # ext.dist intentionally not swapped
 		ext.length <- rev(ext.length);
@@ -248,40 +248,40 @@ stop("Impossible: cross section area too large."); }
 	denom <- area1+area2-cross.area;
 	
 	wrapLab <- function(num){
-		stri = "";
-		if(print.mode[1] == "percent"){
-			stri <- paste(signif(num*100/denom,digits=sigdigs),"%",sep="");
-			if(isTRUE(print.mode[2] == "raw"))
+		stri = '';
+		if(print.mode[1] == 'percent'){
+			stri <- paste(signif(num*100/denom,digits=sigdigs),'%',sep='');
+			if(isTRUE(print.mode[2] == 'raw'))
 			{
-				stri <- paste(stri,"\n(",num,")",sep="");
+				stri <- paste(stri,'\n(',num,')',sep='');
 			}
 		}
-		if(print.mode[1] == "raw")
+		if(print.mode[1] == 'raw')
 		{
 			stri <- num;
-			if(isTRUE(print.mode[2] == "percent"))
+			if(isTRUE(print.mode[2] == 'percent'))
 			{
-				stri <- paste(stri,"\n(",paste(signif(num*100/denom,digits=sigdigs),"%)",sep=""),sep="");
+				stri <- paste(stri,'\n(',paste(signif(num*100/denom,digits=sigdigs),'%)',sep=''),sep='');
 			}
 		}
 		return(stri);
 	}
 	
-#	flog.info(c(area1,area2,cross.area),name="VennDiagramLogger");
+#	flog.info(c(area1,area2,cross.area),name='VennDiagramLogger');
 	
 #	altCross <- cross.area;
 #	altArea1 <- area1;
 #	altArea2 <- area2;
 	
 #	#Do processing on the areas and the cross.area to turn them into the required numbers for printing
-#	if(print.mode[1] == "percent")
+#	if(print.mode[1] == 'percent')
 #	{
 #		denom <- area1+area2-cross.area;
 #		area1 <- area1*100/denom;
 #		area2 <- area2*100/denom;
 #		cross.area <- cross.area*100/denom;
 #	}
-#	else #print.mode[1] == "raw"
+#	else #print.mode[1] == 'raw'
 #	{
 #		denom <- area1+area2-cross.area;
 #		altArea1 <- area1*100/denom;
@@ -289,7 +289,7 @@ stop("Impossible: cross section area too large."); }
 #		altCross <- cross.area*100/denom;
 #	}
 	
-#	flog.info(c(area1,area2,cross.area),name="VennDiagramLogger");
+#	flog.info(c(area1,area2,cross.area),name='VennDiagramLogger');
 
 	# plot scaled, generic pairwise Venn diagram with or without external texts
 	# ALL OF THE BELOW SECTIONS HAVE A SIMILAR STRUCTURE TO THIS IF BRACKET
@@ -362,21 +362,21 @@ stop("Impossible: cross section area too large."); }
                 if(length(cex.prop) > 0){
 
                     if(length(cex.prop) != 1){ 
-                        flog.error("Value passed to cex.prop is not length 1",name="VennDiagramLogger")
-                        stop("Value passed to cex.prop is not length 1")
+                        flog.error('Value passed to cex.prop is not length 1',name='VennDiagramLogger')
+                        stop('Value passed to cex.prop is not length 1')
 			}
 
                     ## figure out what function to use
                     func = cex.prop
-                    if(class(cex.prop) != "function"){
-                        if(cex.prop == "lin"){
+                    if(class(cex.prop) != 'function'){
+                        if(cex.prop == 'lin'){
                             func = function(x) x
                         }
-                        else if(cex.prop == "log10"){
+                        else if(cex.prop == 'log10'){
                             func = log10
                         }
-                        else flog.error(paste0("Unknown value passed to cex.prop: ", cex.prop),name="VennDiagramLogger")
-stop(paste0("Unknown value passed to cex.prop: ", cex.prop))
+                        else flog.error(paste0('Unknown value passed to cex.prop: ', cex.prop),name='VennDiagramLogger')
+stop(paste0('Unknown value passed to cex.prop: ', cex.prop))
                     }
 
                     ## rescale areas
@@ -384,8 +384,8 @@ stop(paste0("Unknown value passed to cex.prop: ", cex.prop))
                     maxArea = max(areas)            
                     for(i in 1:length(areas)){                
                         cex[i] = cex[i] * func(areas[i]) / func(maxArea)
-                        if(cex[i] <= 0) stop(paste0("Error in rescaling of area labels: the label of area ",
-                                  i, " is less than or equal to zero"))
+                        if(cex[i] <= 0) stop(paste0('Error in rescaling of area labels: the label of area ',
+                                  i, ' is less than or equal to zero'))
                     }
                 }
 
@@ -516,10 +516,10 @@ stop(paste0("Unknown value passed to cex.prop: ", cex.prop))
 					x = cross.area.xpos,
 					y = cross.area.ypos,
 					gp = gpar(
-						col = label.col[1],
-						cex = cex[1],
-						fontface = fontface[1],
-						fontfamily = fontfamily[1]
+						col = label.col[2],
+						cex = cex[2],
+						fontface = fontface[2],
+						fontfamily = fontfamily[2]
 						)
 					);
 				grob.list <- gList(grob.list, tmp);
@@ -528,7 +528,7 @@ stop(paste0("Unknown value passed to cex.prop: ", cex.prop))
 					x = c(cross.area.pos + ext.length[2] * (cross.area.xpos - cross.area.pos), cross.area.pos),
 					y = c(0.5 + ext.length[2] * (cross.area.ypos - 0.5), 0.5),
 					gp = gpar(
-						col = label.col[1],
+						col = label.col[2],
 						lwd = ext.line.lwd,
 						lty = ext.line.lty
 						)
@@ -589,8 +589,8 @@ stop(paste0("Unknown value passed to cex.prop: ", cex.prop))
 			cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]);
 			}
 		else {
-			flog.error("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'",name="VennDiagramLogger")
-stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
+			flog.error('Invalid value for "cat.default.pos", should be either "outer" or "text"',name='VennDiagramLogger')
+stop('Invalid value for "cat.default.pos", should be either "outer or "text"');
 			}
 
 		# draw category labels
@@ -787,8 +787,8 @@ stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
 			cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]);
 			}
 		else {
-			flog.error("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'",name="VennDiagramLogger")
-stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
+			flog.error('Invalid value for "cat.default.pos", should be either "outer" or "text"',name='VennDiagramLogger')
+stop('Invalid value for "cat.default.pos", should be either "outer" or "text"');
 			}
 
 		# add category labels
@@ -894,17 +894,17 @@ stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
 			);
 		grob.list <- gList(grob.list, tmp);
 
-		if (cat.default.pos == "outer") {
+		if (cat.default.pos == 'outer') {
 			cat.pos.1 <- find.cat.pos(0.5, 0.5, cat.pos[1], cat.dist[1], max.circle.size);
 			cat.pos.2 <- find.cat.pos(0.5, 0.5, cat.pos[2], cat.dist[2], max.circle.size);
 			}
-		else if (cat.default.pos == "text") {
+		else if (cat.default.pos == 'text') {
 			cat.pos.1 <- find.cat.pos(area.1.pos, 0.5, cat.pos[1], cat.dist[1]);
 			cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]);
 			}
 		else {
-			flog.error("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'",name="VennDiagramLogger")
-stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
+			flog.error('Invalid value for "cat.default.pos", should be either "outer" or "text"',name='VennDiagramLogger')
+stop('Invalid value for "cat.default.pos", should be either "outer" or "text"');
 			}
 
 		tmp <- textGrob(
@@ -1039,8 +1039,8 @@ stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
 			cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]);
 			}
 		else {
-			flog.error("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'",name="VennDiagramLogger")
-stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
+			flog.error('Invalid value for "cat.default.pos", should be either "outer" or "text"',name='VennDiagramLogger')
+stop('Invalid value for "cat.default.pos", should be either "outer" or "text"');
 			}
 
 		tmp <- textGrob(
@@ -1177,8 +1177,8 @@ stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
 			cat.pos.2 <- find.cat.pos(0.7, 0.5, cat.pos[2], cat.dist[2]);
 			}
 		else {
-			flog.error("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'",name="VennDiagramLogger")
-stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
+			flog.error('Invalid value for "cat.default.pos", should be either "outer" or "text"',name='VennDiagramLogger')
+stop('Invalid value for "cat.default.pos", should be either "outer" or "text"');
 			}
 
 		tmp <- textGrob(
